Usage
runDashboard(datType = NULL, isNorm = FALSE, exTable = NULL, repNormFactor = NULL, filenameRoot = NULL, sample1Name = NULL, sample2Name = NULL, erccmix = "RatioPair", erccdilution = 1, spikeVol = 1, totalRNAmass = 1, choseFDR = 0.05, ratioLim = c(-4, 4), signalLim = c(-14, 14), userMixFile = NULL)
Arguments
datType
type is "count" (RNA-Seq) or "array" (microarray),
"count" is unnormalized integer count data (normalized
RNA-Seq data will be accepted in an updated version of
the package), "array" can be normalized or unnormalized
fluorescent intensities from a microarray experiment.
isNorm
default is FALSE, if FALSE then the unnormalized
input data will be
normalized in erccdashboard analysis. If TRUE then
it is expected that the data is already normalized
exTable
data frame, the first column contains names of
genes or transcripts (Feature) and the remaining columns
are expression measures for sample replicates spiked
with ERCC controls
repNormFactor
optional vector of normalization factors for each
replicate, default value is NULL and 75th percentile
normalization will be applied to replicates
filenameRoot
string root name for output files
sample1Name
string name for sample 1 in the gene expression
experiment
sample2Name
string name for sample 2 in the gene expression
experiment
erccmix
Name of ERCC mixture design, "RatioPair" is
default, the other option is "Single"
erccdilution
unitless dilution factor used in dilution of the Ambion
ERCC spike-in mixture solutions
spikeVol
volume in microliters of diluted ERCC mix spiked into
the total RNA samples
totalRNAmass
mass in micrograms of total RNA spiked with diluted ERCC
mixtures
choseFDR
False Discovery Rate for differential expression testing
ratioLim
Limits for ratio axis on MA plot, default is c(-4,4)
signalLim
Limits for ratio axis on MA plot, default is c(-14,14)
userMixFile
optional filename input, default is NULL, if ERCC
control ratio mixtures other than the Ambion product
were used then a userMixFile can be used for the analysis